Learn R Programming

spMC (version 0.3.6)

contour.pemt: Display Contours with Multi-directional Transiograms

Description

The function draws the $2$-D sections contour plots of a multi-directional transiogram computed without any ellipsoidal interpolation and superpose the contour lines of the theoretical transition probabilities.

Usage

"contour"(x, nlevels = 10, col = c("black", "blue"), main, mar, ask = TRUE, ...)

Arguments

x
an object of class pemt.
nlevels
the number of levels to pass to the function contour.
col
a vector of two colors to pass to the function contour. The former color refers to the multi-directional transiogram, while the latter is used to draw contour lines of the theoretical transition probabilities.
main
the main title (on top) whose font and size are fixed.
mar
a scalar or a numerical vector of the form c(bottom, left, top, right) which gives the number of margin lines to be specified on the four sides of image to plot. See par(mar=.).
ask
a logical value; if TRUE, the user is asked for input, before each plot. See par(ask=.).
...
other arguments to pass to the function contour.

Value

Details

A multidimensional transiogram is a diagram which shows the transition probabilities for a single pair of categories. The probability is computed for any lag vector $h$ through $$\mbox{expm} (\Vert h \Vert R_h),$$ where entries of $R$ are not ellipsoidally interpolated, but they are estimated for the direction specified by the vector $h$.

The exponential matrix is evaluated by the scaling and squaring algorithm.

References

Carle, S. F., Fogg, G. E. (1997) Modelling Spatial Variability with One and Multidimensional Continuous-Lag Markov Chains. Mathematical Geology, 29(7), 891-918.

Higham, N. J. (2008) Functions of Matrices: Theory and Computation. Society for Industrial and Applied Mathematics.

Sartore, L. (2010) Geostatistical models for 3-D data. M.Phil. thesis, Ca' Foscari University of Venice.

See Also

image.pemt, contour, plot.transiogram