Learn R Programming

spMC (version 0.3.6)

is.tpfit: Object test for tpfit class

Description

Function to test if an object is of the class tpfit.

Usage

is.tpfit(object)

Arguments

object
object to be tested.

Value

Details

The function returns TRUE if and only if its argument is a tpfit object.

See Also

tpfit