Learn R Programming

spMC (version 0.3.6)

print.tpfit: Printing Model Parameters for One-dimensional Continuous Lag Spatial MC

Description

The function prints parameter estimation results given by tpfit.

Usage

"print"(x, ...)

Arguments

x
an object of the class tpfit, typically with the output of the function tpfit.
...
further arguments passed to or from other methods.

Value

See Also

tpfit