tpfit_ils(data, coords, direction, max.dist = Inf, mpoints = 20, tolerance = pi/8, q = 10, echo = FALSE, ..., tpfit)Inf by default.pi/8 by default.10 by default.TRUE, the function prints some information about the optimization. It is FALSE by default.nlminb.tpfit to optimize. If missing, the algorithm starts with a null transition rates matrix.tpfit is returned. The function print.tpfit is used to print the fitted model. The object is a list with the following components:
To calculate entries of the transition rate matrix, we need to minimize the discrepancies between the empirical transiogram (see transiogram) and the predicted transition probabilities.
By the use of the iterated least squares, the diagonal entries of $R$ are constrained to be negative, while the off-diagonal transition rates are constrained to be positive. Further constraints are considered in order to obtain a proper transition rates matrix.
predict.tpfit, print.tpfit, multi_tpfit_ils, transiogram