tpfit_me(data, coords, direction, tolerance = pi/8, max.it = 9000, mle = "avg")pi/8 by default.9000 by default.mlen. It is "avg" by default.tpfit is returned. The function print.tpfit is used to print the fitted model. The object is a list with the following components:
To calculate entries of the transition rate matrix, we need to maximize the entropy of the transition probabilities of embedded occurrences along a given direction $phi$. The entropy is defined as $$e = - \sum_{k}^K \sum_{j \neq k}^K \tau_{jk, \phi} \log \tau_{jk, \phi},$$ where $tau_(jk, phi)$ are transition probabilities of embedded occurrences. It is maximized by the use of the iterative proportion fitting method.
When some entries of the matrix $R$ are not identifiable, it is suggested to vary the tolerance coefficient or to set the input argument mle to "mlk".
predict.tpfit, print.tpfit, multi_tpfit_me