"contour"(x, nlevels = 10, col = c("black", "blue"), main, mar, ask = TRUE, ...)pemt.contour.contour. The former color refers to the multi-directional transiogram, while the latter is used to draw contour lines of the theoretical transition probabilities.c(bottom, left, top, right) which gives the number of margin lines to be specified on the four sides of image to plot. See par(mar=.).TRUE, the user is asked for input, before each plot. See par(ask=.).contour.The exponential matrix is evaluated by the scaling and squaring algorithm.
Higham, N. J. (2008) Functions of Matrices: Theory and Computation. Society for Industrial and Applied Mathematics.
Sartore, L. (2010) Geostatistical models for 3-D data. M.Phil. thesis, Ca' Foscari University of Venice.
image.pemt, contour, plot.transiogram