Learn R Programming

spMC (version 0.3.2)

contour.pemt: Display Contours with Multi-directional Transiograms

Description

The function draws the $2$-D sections contour plots of a multi-directional transiogram computed without any ellipsoidal interpolation and superpose the contour lines of the theoretical transition probabilities.

Usage

## S3 method for class 'pemt':
contour(x, nlevels = 10, col = c("black", "blue"), main,
     mar, ask = TRUE, ...)

Arguments

Value

An image is produced on the current graphics device. No values are returned.

Rdversion

1.1

Details

A multidimensional transiogram is a diagram which shows the transition probabilities for a single pair of categories. The probability is computed for any lag vector $h$ through $$\mbox{expm} (\Vert h \Vert R_h),$$ where entries of $R_h$ are not ellipsoidally interpolated, but they are estimated for the direction specified by the vector $h$.

The exponential matrix is evaluated by the scaling and squaring algorithm.

References

Carle, S. F., Fogg, G. E. (1997) Modelling Spatial Variability with One and Multidimensional Continuous-Lag Markov Chains. Mathematical Geology, 29(7), 891-918.

Higham, N. J. (2008) Functions of Matrices: Theory and Computation. Society for Industrial and Applied Mathematics.

Sartore, L. (2010) Geostatistical models for 3-D data. M.Phil. thesis, Ca' Foscari University of Venice.

See Also

image.pemt, contour, plot.transiogram

Examples

Run this code
data(ACM)

# Compute a 2-D section of a 
# multi-directional transiogram
psEmpTr <- pemt(ACM$MAT3, ACM[, 1:3], 2,
                max.dist = c(200, 200, 20), 
                which.dire=c(1, 3), 
                mle = "avg")

# Contour plots of 2-D sections of 
# multi-directional transiograms
contour(psEmpTr, mar = .7)

Run the code above in your browser using DataLab