"persp"(x, main, mar, ask = TRUE, col = "white", ...)pemt, typically with the output of the function pemt.c(bottom, left, top, right) which gives the number of margin lines to be specified on the four sides of image to plot. See par(mar=.).TRUE, the user is asked for input, before each plot. See par(ask=.).rev(heat.colors()), or with other function for colors.persp.The exponential matrix is evaluated by the scaling and squaring algorithm.
Higham, N. J. (2008) Functions of Matrices: Theory and Computation. Society for Industrial and Applied Mathematics.
Sartore, L. (2010) Geostatistical models for 3-D data. M.Phil. thesis, Ca' Foscari University of Venice.
pemt, persp.multi_tpfit, persp, multi_tpfit, image.pemt, plot.transiogram